==> json-joy-2.17.0.tgz: package/esm/binary-rx/codec/Encoder.js <==
import { writeHeader } from './header';
import { DataMessage } from '../messages/DataMessage';
import { NotificationMessage } from '../messages/NotificationMessage';
import { SubscribeMessage } from '../messages/SubscribeMessage';
import { CompleteMessage } from '../messages/CompleteMessage';
import { ErrorMessage } from '../messages/ErrorMessage';
import { UnsubscribeMessage } from '../messages/UnsubscribeMessage';
export class Encoder {
    constructor() {
        this.uint8 = new Uint8Array(0);
        this.offset = 0;
    }
    encode(messages) {
        let size = 0;
        const length = messages.length;
        for (let i = 0; i < length; i++)
            size += messages[i].size();
        this.uint8 = new Uint8Array(size);
        this.offset = 0;
        for (let i = 0; i < length; i++) {
            const message = messages[i];
            if (message instanceof NotificationMessage)
                this.notif(message);
            else if (message instanceof SubscribeMessage)
                this.sub(message);
            else if (message instanceof DataMessage)
                this.data(message);
            else if (message instanceof CompleteMessage)
                this.comp(message);
            else if (message instanceof ErrorMessage)
                this.err(message);
            else if (message instanceof UnsubscribeMessage)
                this.unsub(message);
        }
        return this.uint8;
    }
    notif(message) {
        const { method, data } = message;
        const length = data ? data.byteLength : 0;
        this.header(0, length);
        this.method(method);
        if (length) {
            this.uint8.set(data, this.offset);
            this.offset += length;
        }
    }
    sub(message) {
        const { id, method, data } = message;
        const length = data ? data.byteLength : 0;
        this.header(1, length);
        this.id(id);
        this.method(method);
        if (length) {
            this.uint8.set(data, this.offset);
            this.offset += length;
        }
    }
    data(message) {
        this.msgWithId(2, message.id, message.data);
    }
    comp(message) {
        this.msgWithId(3, message.id, message.data);
    }
    err(message) {
        this.msgWithId(5, message.id, message.data);
    }
    unsub(message) {
        this.uint8[this.offset++] = 4 << 5;
        this.id(message.id);
    }
    msgWithId(code, id, data) {
        const length = data ? data.byteLength : 0;
        this.header(code, length);
        this.id(id);
        if (length) {
            this.uint8.set(data, this.offset);
            this.offset += length;
        }
    }
    header(code, length) {
        this.offset = writeHeader(this.uint8, this.offset, code, length);
    }
    id(id) {
        this.uint8[this.offset++] = id >>> 8;
        this.uint8[this.offset++] = id & 0xff;
    }
    method(method) {
        const uint8 = this.uint8;
        const length = method.length;
        let offset = this.offset;
        uint8[offset++] = length;
        for (let i = 0; i < length; i++)
            uint8[offset++] = method.charCodeAt(i);
        this.offset = offset;
    }
}

==> json-joy-7.11.0.tgz: package/esm/binary-rx/codec/Encoder.js <==
import { writeHeader } from './header';
import { DataMessage } from '../messages/DataMessage';
import { NotificationMessage } from '../messages/NotificationMessage';
import { SubscribeMessage } from '../messages/SubscribeMessage';
import { CompleteMessage } from '../messages/CompleteMessage';
import { ErrorMessage } from '../messages/ErrorMessage';
import { UnsubscribeMessage } from '../messages/UnsubscribeMessage';
export class Encoder {
    uint8 = new Uint8Array(0);
    offset = 0;
    encode(messages) {
        let size = 0;
        const length = messages.length;
        for (let i = 0; i < length; i++)
            size += messages[i].size();
        this.uint8 = new Uint8Array(size);
        this.offset = 0;
        for (let i = 0; i < length; i++) {
            const message = messages[i];
            if (message instanceof NotificationMessage)
                this.notif(message);
            else if (message instanceof SubscribeMessage)
                this.sub(message);
            else if (message instanceof DataMessage)
                this.data(message);
            else if (message instanceof CompleteMessage)
                this.comp(message);
            else if (message instanceof ErrorMessage)
                this.err(message);
            else if (message instanceof UnsubscribeMessage)
                this.unsub(message);
        }
        return this.uint8;
    }
    notif(message) {
        const { method, data } = message;
        const length = data ? data.byteLength : 0;
        this.header(0, length);
        this.method(method);
        if (length) {
            this.uint8.set(data, this.offset);
            this.offset += length;
        }
    }
    sub(message) {
        const { id, method, data } = message;
        const length = data ? data.byteLength : 0;
        this.header(1, length);
        this.id(id);
        this.method(method);
        if (length) {
            this.uint8.set(data, this.offset);
            this.offset += length;
        }
    }
    data(message) {
        this.msgWithId(2, message.id, message.data);
    }
    comp(message) {
        this.msgWithId(3, message.id, message.data);
    }
    err(message) {
        this.msgWithId(5, message.id, message.data);
    }
    unsub(message) {
        this.uint8[this.offset++] = 4 << 5;
        this.id(message.id);
    }
    msgWithId(code, id, data) {
        const length = data ? data.byteLength : 0;
        this.header(code, length);
        this.id(id);
        if (length) {
            this.uint8.set(data, this.offset);
            this.offset += length;
        }
    }
    header(code, length) {
        this.offset = writeHeader(this.uint8, this.offset, code, length);
    }
    id(id) {
        this.uint8[this.offset++] = id >>> 8;
        this.uint8[this.offset++] = id & 0xff;
    }
    method(method) {
        const uint8 = this.uint8;
        const length = method.length;
        let offset = this.offset;
        uint8[offset++] = length;
        for (let i = 0; i < length; i++)
            uint8[offset++] = method.charCodeAt(i);
        this.offset = offset;
    }
}
